tokenizer\_tools.format\_converter package
==========================================

Submodules
----------

tokenizer\_tools.format\_converter.corpus\_to\_rasa\_json module
----------------------------------------------------------------

.. automodule:: tokenizer_tools.format_converter.corpus_to_rasa_json
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.format_converter
   :members:
   :undoc-members:
   :show-inheritance:
